@@ -66,9 +66,10 @@ extern "C" {
  * Use ROOT as the filesystem root. If ROOT is NULL, use the value of the
  * environment variable AUGEAS_ROOT. If that doesn't exist eitehr, use "/".
  *
- * LOADPATH is a colon-spearated list of directories that modules should be
+ * LOADPATH is a colon-separated list of directories that modules should be
  * searched in. This is in addition to the standard load path and the
- * directories in AUGEAS_LENS_LIB
+ * directories in AUGEAS_LENS_LIB. LOADPATH can be NULL, indicating that
+ * nothing should be added to the load path.
  *
  * FLAGS is a bitmask made up of values from AUG_FLAGS. The flag
  * AUG_NO_ERR_CLOSE can be used to get more information on why
@@ -403,12 +404,25 @@ int aug_print(const augeas *aug, FILE *out, const char *path);
  * contain the path to the toplevel node of that file underneath /files. If
  * it does not, *FILE_PATH will be NULL.
  *
+ * The caller is responsible for freeing *FILE_PATH
+ *
  * Returns:
  * 0 on success, or a negative value on failure. It is an error if PATH
  * matches more than one node.
  */
 int aug_source(const augeas *aug, const char *path, char **file_path);
 
+/* Function: aug_preview
+ *
+ * Return the contents of the file that would be written for the file associated with path
+ * If there is no file corresponfing to PATH, *OUT will be NULL.
+ * The caller is responsible for freeing *OUT
+ *
+ * Returns:
+ * 0 on success, -1 on error
+ */
+int aug_preview(augeas *aug, const char *path, char **out);
+
 /* Function: aug_to_xml
  *
  * Turn the Augeas tree(s) matching PATH into an XML tree XMLDOC. The
@@ -585,7 +599,8 @@ typedef enum {
     AUG_ECMDRUN,        /* Failed to execute command */
     AUG_EBADARG,        /* Invalid argument in function call */
     AUG_ELABEL,         /* Invalid label */
-    AUG_ECPDESC         /* Cannot copy node into its descendant */
+    AUG_ECPDESC,        /* Cannot copy node into its descendant */
+    AUG_EFILEACCESS     /* Cannot open or read a file */
 } aug_errcode_t;
 
 /* Return the error code from the last API call */
